@@ -50,6 +50,90 @@
 using namespace KPIM;
 static const int MAX_LABEL_WIDTH = 650;
 
+class KPIM::OverlayWidgetPrivate
+{
+public:
+    OverlayWidgetPrivate()
+    {
+    }
+
+    QWidget *mAlignWidget = nullptr;
+};
+
+OverlayWidget::OverlayWidget(QWidget *alignWidget, QWidget *parent)
+    : QFrame(parent)
+    , d(new KPIM::OverlayWidgetPrivate)
+{
+    setAlignWidget(alignWidget);
+    setLayout(new QHBoxLayout(this));
+}
+
+OverlayWidget::~OverlayWidget()
+{
+    delete d;
+}
+
+QWidget *OverlayWidget::alignWidget() const
+{
+    return d->mAlignWidget;
+}
+
+void OverlayWidget::reposition()
+{
+    if (!d->mAlignWidget) {
+        return;
+    }
+    // p is in the alignWidget's coordinates
+    QPoint p;
+    // We are always above the alignWidget, right-aligned with it for
+    // LTR locales, and left-aligned for RTL locales (default value=0).
+    if (layoutDirection() == Qt::LeftToRight) {
+        p.setX(d->mAlignWidget->width() - width());
+    }
+    p.setY(-height());
+    // Position in the toplevelwidget's coordinates
+    QPoint pTopLevel = d->mAlignWidget->mapTo(topLevelWidget(), p);
+    // Position in the widget's parentWidget coordinates
+    QPoint pParent = parentWidget()->mapFrom(topLevelWidget(), pTopLevel);
+    // Move 'this' to that position.
+    move(pParent);
+}
+
+void OverlayWidget::setAlignWidget(QWidget *w)
+{
+    if (w == d->mAlignWidget) {
+        return;
+    }
+
+    if (d->mAlignWidget) {
+        d->mAlignWidget->removeEventFilter(this);
+    }
+
+    d->mAlignWidget = w;
+
+    if (d->mAlignWidget) {
+        d->mAlignWidget->installEventFilter(this);
+    }
+
+    reposition();
+}
+
+bool OverlayWidget::eventFilter(QObject *o, QEvent *e)
+{
+    if (o == d->mAlignWidget
+        && (e->type() == QEvent::Move || e->type() == QEvent::Resize)) {
+        reposition();
+    }
+    return QFrame::eventFilter(o, e);
+}
+
+void OverlayWidget::resizeEvent(QResizeEvent *ev)
+{
+    reposition();
+    QFrame::resizeEvent(ev);
+}
+
+
 TransactionItemView::TransactionItemView(QWidget *parent, const QString &name)
     : QScrollArea(parent)
 {
@@ -57,7 +141,7 @@ TransactionItemView::TransactionItemView(QWidget *parent, const QString &name)
     setFrameStyle(NoFrame);
     mBigBox = new QWidget(this);
     QVBoxLayout *mBigBoxVBoxLayout = new QVBoxLayout(mBigBox);
-    mBigBoxVBoxLayout->setMargin(0);
+    mBigBoxVBoxLayout->setContentsMargins(0, 0, 0, 0);
     setWidget(mBigBox);
     setWidgetResizable(true);
     setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
@@ -139,7 +223,7 @@ TransactionItem::TransactionItem(QWidget *parent, ProgressItem *item, bool first
 {
     QVBoxLayout *vboxLayout = new QVBoxLayout(this);
     vboxLayout->setSpacing(2);
-    vboxLayout->setMargin(2);
+    vboxLayout->setContentsMargins(2, 2, 2, 2);
     setSizePolicy(QSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed));
 
     mFrame = new QFrame(this);
@@ -150,7 +234,7 @@ TransactionItem::TransactionItem(QWidget *parent, ProgressItem *item, bool first
 
     QWidget *h = new QWidget(this);
     QHBoxLayout *hHBoxLayout = new QHBoxLayout(h);
-    hHBoxLayout->setMargin(0);
+    hHBoxLayout->setContentsMargins(0, 0, 0, 0);
     hHBoxLayout->setSpacing(5);
     layout()->addWidget(h);
 
@@ -176,7 +260,7 @@ TransactionItem::TransactionItem(QWidget *parent, ProgressItem *item, bool first
 
     h = new QWidget(this);
     hHBoxLayout = new QHBoxLayout(h);
-    hHBoxLayout->setMargin(0);
+    hHBoxLayout->setContentsMargins(0, 0, 0, 0);
     hHBoxLayout->setSpacing(5);
     h->setSizePolicy(QSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed));
     layout()->addWidget(h);
